Stan Math Library: stan/math/prim/mat/fun/log.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

log.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_LOG_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_LOG_HPP
3
4 #include <stan/math/prim/mat/fun/Eigen.hpp>
5
6 namespace stan {
7 namespace math {
8
15 template<typename T, int Rows, int Cols>
16 inline Eigen::Matrix<T, Rows, Cols>
17 log(const Eigen::Matrix<T, Rows, Cols>& m) {
18 return m.array().log().matrix();
19 }
20
21
22 }
23 }
24 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::log
fvar< T > log(const fvar< T > &x)
Definition: log.hpp:15
Eigen.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.